#
# spec file for package python-python3-saml
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-python3-saml
Version:        1.7.0
Release:        150400.8.4
Summary:        Python SAML support
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/onelogin/python3-saml
Source:         https://github.com/onelogin/python3-saml/archive/v.%{version}.tar.gz#/python3-saml-%{version}.tar.gz
# PATCH-FIX-UPSTREAM bug-testDecryptElement.patch mcepl@suse.com
# Different versions in different versions of SLE-15 produce different decrypted_nameid.tag
Patch0:         bug-testDecryptElement.patch
# PATCH-FIX-UPSTREAM bsc#1197846 mcalabkova@suse.com
# update various expired security certificates and such
# patch from gh#onelogin/python3-saml#269
Patch1:         269-update-expiry-date-for-responses.patch
Patch2:         additional-expired-resources.patch
BuildRequires:  %{python_module defusedxml >= 0.5.0}
BuildRequires:  %{python_module freezegun >= 0.3.11}
BuildRequires:  %{python_module isodate >= 0.5.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module xmlsec >= 0.6.0}
BuildRequires:  fdupes
BuildRequires:  libxmlsec1-openssl1
BuildRequires:  python-rpm-macros
# Select the libxmlsec backend known to work
# pkgconfig doesnt auto-require it.
Requires:       libxmlsec1-openssl1
Requires:       python-defusedxml >= 0.5.0
Requires:       python-isodate >= 0.5.0
Requires:       python-xmlsec >= 0.6.0
BuildArch:      noarch
%python_subpackages

%description
Python SAML support for your Python 2 or 3 software.

SAML is an XML-based standard for web browser single sign-on and is
defined by the OASIS Security Services Technical Committee.

%prep
%setup -q -n python3-saml-v.%{version}
%autopatch -p1

sed -i 's/==/>=/;/dependency_links/d' setup.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}/onelogin

%check
%python_exec setup.py test

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitelib}/onelogin
%{python_sitelib}/python3_saml-*-info

%changelog
* Thu Apr  7 2022 mmachova@suse.com
- Add patch 269-update-expiry-date-for-responses.patch to fix
  bsc#1197846 (originally from gh#onelogin/python3-saml#269).
- Add additional-expired-resources.patch with some more updated
  expired resources.
- Update bug-testDecryptElement.patch to work for SP2 and SP4.
* Mon Jul 22 2019 tchvatal@suse.com
- Update to 1.7.0:
  * Adjusted acs endpoint to extract NameQualifier and SPNameQualifier from
    SAMLResponse.
  * Adjusted single logout service to provide NameQualifier and SPNameQualifier
    to logout method.
  * Add getNameIdNameQualifier to Auth and SamlResponse.
  * Extend logout method from Auth and LogoutRequest constructor to support.
  * Added get_in_response_to method to Response and LogoutResponse classes
  * Update defusexml dependency
* Wed Apr 10 2019 jayvdb@gmail.com
- Add explicit dependency on libxmlsec1-openssl1, recommended
  by dependency python-xmlsec so this package may be used without
  needing to select a libxmlsec backend
- Activate test suite, adding bug-testDecryptElement.patch to
  workaround a test failure, and remove bcond test
- Build for Python 2, as support has been added upstream
- Remove unnecessary build dependency on python-devel
- Use %%license
- Remove live dependency_links and remove == pins from setup.py,
  so installed egg-info isnt broken
- Update to v1.6.0
  * Add support for Subjects on AuthNRequests by the new
    name_id_value_req parameter
  * Fix for SLO when XML specifies encoding
  * Fixed setting NameFormat attribute for AttributeValue tags
- from v1.5.0
  * Security improvements. Use of tagid to prevent XPath injection
    Disable DTD on fromstring defusedxml method
  * Check that the response has all of the AuthnContexts provided
  * Adapt renders from Django demo for Django 1.11 version
  * If debug enable, print reason for the SAMLResponse invalidation
  * Fix DSA constant
  * Support NameID children inside of AttributeValue elements
- from v1.4.1
  * Add ID to EntityDescriptor before sign it on add_sign method
  * Update defusedxml dependencies
  * Update copyright and license reference
- from 1.4.0
  * Fix CVE-2017-11427. Process text of nodes properly, ignoring comments
  * Improve how fingerprint is calcultated
  * Fix issue with LogoutRequest rejected by ADFS due NameID with
    unspecified format instead no format attribute
  * Fix signature position in the SP metadata
  * Preserve xmlns:xs namespace when signing and serializing responses
  * Redefine NSMAP constant
  * Updated Django demo (Django 1.11)
* Wed Oct 25 2017 sean.marlow@suse.com
- Intial package. v1.3.0
